# Week 09: Routing & Forms Demo

In this demo, you are going to finish implementation of the very simple **Products store**. The features are:

- Browsing available products
- Ordering **one** specific product in **several steps**:
  - Specifying customer, delivery and payment details
  - Seeing summary
  - Confirmation

This time, we will focus just on frontend. Mainly on:

- Routing **using Route objects**
- Advanced forms with **react-hook-form**

Built using **[Material UI](https://mui.com/material-ui/)**.

## Installation

```bash
npm i
```

## Run the application

```bash
npm run dev
```

## Notes on structure

- `src/layouts/MainLayout.tsx` - Each page except of **Not found** page (`src/pages/errors/NotFound.tsx`) uses this layout.
- `src/layouts/order/OrderLayout.tsx` - Each **Order** page (`src/pages/order/*`) uses this layout. It contains a **Stepper** which guides the customer through the order.
- `src/types/*` - Types of all the objects used in the application inferred from **validation schemas** (`src/validationSchemas/forms.ts`).
- `src/data/products.json` - Serves as a db of products.
- `src/hooks/useProduct.ts` - Hook used by **Order pages** to get **product by its id** which can be obtained from **URL params**.
- `src/hooks/useOrderData.ts` - Hook which ensures persistence of the product order. It's also important for `src/hooks/useOrderSteps.ts` hook to deduce active step, disabled and completed steps.

## Notes on import

Thanks to the **Vite configuration** and **TS configuration** it's possible to import **components** from everywhere like:

```tsx
import OrderPaymentDetails from "@/pages/order/OrderPaymentDetails"
```

instead of:

```tsx
import OrderPaymentDetails from "../../../../pages/order/OrderPaymentDetails"
```

The same applies to:

- `src/hooks` -> `@/hooks`
- `src/data` -> `@/data`
- etc.

## Files to be edited

Edit the following files in the order specified:

- `src/router/routes.tsx`
- `src/router/index.ts`
- `src/hooks/useProduct.ts`
- `src/validationSchemas/forms.ts`
- `src/pages/order/*Details.tsx`

## Tasks

The tasks are following:

### 1. Create routes

Create routes (`RouteObject[]`) to be passed to the router in `src/router/routes.tsx` file:

**Main layout**

- `/` <-> Redirect to `/home` using `Navigate` component.
- `/home` <-> `src/pages/Home.tsx`
- `/products` <-> `src/pages/Products.tsx`

**Order layout**

Uses implicitely **Main layout**. All the routes contain `productId` **URL param**.

- `/order/:productId` <-> Redirect to `/order/:productId/customer-details`.
- `/order/:productId/customer-details` <-> `src/pages/order/OrderCustomerDetails.tsx`
- Analogously to `customer-details` **add** `delivery-details`, `payment-details`, `summary` and `confirmation`.

**Errors (no layout)**

- Any **invalid** route (404 not found) <-> `src/pages/errors/NotFound.tsx`.

**Checkpoint**

If you've done everything correctly, you should see the following in the Navbar:

- **Dark grey background** on the **Home** button when you're at the **Welcome page**.
- **Dark grey background** on the **Products** button when you're on the **List of products**.
- It won't let you get to any **Order page** yet (redirects you back). 

Also try to type some invalid URL such as `<BASE_URL>/categories` or `<BASE_URL>/order` (missing `productId` param). You should see contents of the **Not Found page** (`src/pages/errors/NotFound.tsx`).

### 2. Make useProduct hook working

Finish implementation of the `useProduct` hook in the `src/hooks/useProduct.ts` file. Assume that this hook is used on the **Order pages** and therefore `productId` URL param should be specified. You need to:

- Get value of the `productId` URL param.
- You should use some **React router hook** dedicated for that.

**Checkpoint**

If you've done everything correctly:

- Typing `<BASE_URL>/order/1` should successfully redirect you to the first **Order step**.
- Typing `<BASE_URL>/order/notnumber/customer-details` should redirect you to `<BASE_URL>/products`.

### 3. Finish validation schemas

Finish implementation of the validation schemas in the `src/validationSchemas/forms.ts` file.

Note: you should use **[Validator](https://www.npmjs.com/package/validator)** functions like `isCreditcard` here.

### 4. Advanced forms

Finish implementation of forms in `src/pages/order/*Details.tsx` files:
- **Default values** - provided in `orderData` via `useOrderData` hook.
- **Submission** - user can't get to another step until the data are valid. Navigate to the next step when submitted.
- **Validation** and **error handling** - provide helper text with error message to the user.

TODO comments should tell you more. You may also find useful **Test data** which are provided for you on the bottom of each **Order** page.
