import AppBar from '@mui/material/AppBar'
import Toolbar from '@mui/material/Toolbar'
import { Button, ButtonGroup, Container, IconButton, Tooltip } from '@mui/material'
import { Link, NavLink } from 'react-router-dom'
import { useTheme } from '@mui/material/styles'
import Logo from "@/assets/store.svg?react"

const pathAndTitle: Record<string, string> = {
  '/home': 'Home',
  '/products': 'Products',
}

export function Navbar() {
  const theme = useTheme()

  return (
    <AppBar position="static" sx={{ width: '100%' }} color="custom">
      <Container disableGutters>
        <Toolbar>
          <Tooltip title="Home">
            <IconButton component={Link} to="/" sx={{ mr: 2 }}>
              <Logo width={25} height={25} fill={theme.palette.secondary.main} />
            </IconButton> 
          </Tooltip>
          <ButtonGroup variant="text" color="dark">
            {Object.keys(pathAndTitle).map(path =>
              <Button
                key={path}
                component={NavLink}
                to={path}
                sx={{ px: 3, '&.active': {
                  backgroundColor: theme.palette.dark.main,
                  color: theme.palette.dark.contrastText
                } }}
              >
                {pathAndTitle[path]}
              </Button>
            )}
          </ButtonGroup>
        </Toolbar>
      </Container>
    </AppBar>
  )
}
  
export default Navbar
  