import { useMemo } from 'react'
import useOrderData from './useOrderData'
import { useNavigate } from 'react-router-dom'
import useProduct from './useProduct'

interface OrderStep {
  label: string;
  path: string;
}

const orderSteps: OrderStep[] = [
  {
    label: 'Customer Details',
    path: 'customer-details',
  },
  {
    label: 'Delivery Details',
    path: 'delivery-details',
  },
  {
    label: 'Payment Details',
    path: 'payment-details',
  },
  {
    label: 'Summary',
    path: 'summary',
  },
  {
    label: 'Confirmation',
    path: 'confirmation',
  }
]

const useOrderSteps = () => {
  const { orderData } = useOrderData()
  const { product } = useProduct()
  const navigate = useNavigate()
  
  const activeStep = useMemo<number>(() => {
    if (typeof orderData.customerDetails === 'undefined') {
      return 0
    }

    if (typeof orderData.deliveryDetails === 'undefined') {
      return 1
    }

    if (typeof orderData.paymentDetails === 'undefined') {
      return 2
    }

    return orderData.confirmed ? 4 : 3
  }, [orderData])
  
  const isStepDisabled = (step: number) => {
    return step !== activeStep && !isStepCompleted(step)
  }
   
  const isStepCompleted = (step: number) => {
    return step < activeStep
  }
  
  const handleStep = ((step: number) => (() => {
    if (!isStepDisabled(step) && !orderData.confirmed) {
        navigate(`/order/${product?.id}/${orderSteps[step].path}`)
    }
  }))
  
  return { steps: orderSteps, activeStep, handleStep, isStepDisabled, isStepCompleted }
}

export default useOrderSteps