import Page from "@/components/base/Page"
import { Button, Grid, List, ListItem, ListItemText, Paper, Typography } from "@mui/material"
import products from "@/data/products.json"
import type Product from "@/types/product"
import { Link } from "react-router-dom"
import useOrderData from "@/hooks/useOrderData"

export function Products() {
  const { resetData } = useOrderData()

    return (
      <Page title="Products">
        <Typography component="h2" variant="h5" mb={3} color="secondary.main">
          Here is the list of available products:
        </Typography>

        <Grid container>
          <Grid item xs={12} sm={10} md={8} lg={6}>
            <Paper elevation={2}>
              <List>
                {products.map((product: Product) => 
                  <ListItem key={product.id}>
                    <ListItemText primary={product.name} />
                    <Button
                      variant="contained"
                      color="custom"
                      component={Link}
                      to={`/order/${product.id}/customer-details`}
                      onClick={resetData}
                    >
                        Order
                    </Button>
                  </ListItem>
                )}
              </List>
            </Paper>
          </Grid>
        </Grid>
      </Page>
    )
  }
  
export default Products