import useOrderData from "@/hooks/useOrderData"
import useProduct from "@/hooks/useProduct"
import { Box, Button, ButtonGroup, Tooltip, Typography } from "@mui/material"
import { Link, Navigate } from "react-router-dom"

export function OrderSummary() {
  const { orderData, updateOrderData } = useOrderData()
  const { product } = useProduct()

  const onConfirm = () => {
    updateOrderData({ ...orderData, confirmed: true, productId: product?.id })
  }

  if (orderData.confirmed) {
    return <Navigate to="../confirmation" relative="path" />
  }

  return (
      <>
        <Box mb={3}>
          <Typography color="primary.main" component="h2" variant="h5" mt={2} mb={1}>
            Customer
          </Typography>
          <Typography color="secondary.main" component="p" variant="h6">
            Name:{' '}
            <Typography component="b" color="inherit" variant="inherit" fontWeight="bold">{orderData.customerDetails?.name}</Typography>.
          </Typography>
          <Typography color="secondary.main" component="p" variant="h6">
            Phone number:{' '}
            <Typography component="b" color="inherit" variant="inherit" fontWeight="bold">{orderData.customerDetails?.phoneNumber}</Typography>.
          </Typography>
          <Typography color="secondary.main" component="p" variant="h6">
            E-mail Address:{' '}
            <Typography component="b" color="inherit" variant="inherit" fontWeight="bold">{orderData.customerDetails?.email}</Typography>.
          </Typography>
          <Typography color="primary.main" component="h2" variant="h5" mt={2} mb={1}>
            Delivery
          </Typography>
          <Typography color="secondary.main" component="p" variant="h6">
            Address:{' '}
            <Typography component="b" color="inherit" variant="inherit" fontWeight="bold">
              {orderData.deliveryDetails?.street}{' '}
              {orderData.deliveryDetails?.houseNo},{' '}
              {orderData.deliveryDetails?.city}{' '}
              {orderData.deliveryDetails?.postalCode},{' '}
              {orderData.deliveryDetails?.country}
            </Typography>.
          </Typography>
          <Typography color="primary.main" component="h2" variant="h5" mt={2} mb={1}>
            Payment
          </Typography>
          <Typography color="secondary.main" component="p" variant="h6">
            Credit Card Number:{' '}
            <Typography component="b" color="inherit" variant="inherit" fontWeight="bold">{orderData.paymentDetails?.cardNumber}</Typography>.
          </Typography>
          <Typography color="secondary.main" component="p" variant="h6">
            Expiration:{' '}
            <Typography component="b" color="inherit" variant="inherit" fontWeight="bold">
              {orderData.paymentDetails?.expirationMonth}/
              {orderData.paymentDetails?.expirationYear.toString().slice(2)}
            </Typography>.
          </Typography>
          <Typography color="secondary.main" component="p" variant="h6">
            Cvv:{' '}
            <Typography component="b" color="inherit" variant="inherit" fontWeight="bold">{orderData.paymentDetails?.cvv}</Typography>.
          </Typography>
          <Typography color="secondary.main" component="p" variant="h6">
            Holder:{' '}
            <Typography component="b" color="inherit" variant="inherit" fontWeight="bold">{orderData.paymentDetails?.holder}</Typography>.
          </Typography>
        </Box>
        <ButtonGroup variant="contained">
          <Tooltip title="Confirmation cannot be undone">
            <Button color="primary" onClick={onConfirm}>Confirm</Button>
          </Tooltip>
          <Tooltip title="Payment details">
            <Button component={Link} color="dark" to="../payment-details" relative="path">Back</Button>
          </Tooltip>
        </ButtonGroup>
      </>
    )
  }
  
export default OrderSummary