import z from 'zod'
import isMobilePhone from "validator/lib/isMobilePhone"

export const customerDetailsSchema = z.object({
  name: z.string().min(1, "Name is required.").max(100, "Name is too long."),
  phoneNumber: z.string().min(1, "Phone number is required.").refine(isMobilePhone, "Phone number is invalid."),
  // TODO: validate better using validator library.
  email: z.string().min(1, "E-mail address is required."),
  agreedTerms: z.boolean().refine(val => val, 'You need to agree with the terms to continue.'),
})

export const deliveryDetailsSchema = z.object({
  city:  z.string().min(1, "City is required.").max(100, "City is too long."),
  // TODO: validate better using validator library.
  postalCode: z.string().min(1, 'Postal code is required.'),
  street: z.string().min(1, "Street is required.").max(100, "Street is too long."),
  houseNo: z.string().min(1, 'House no is required.').pipe(z.coerce.number({
    invalid_type_error: 'House no is a number.'
  }).min(1, "House no is too small.").max(100000, "House no is too large.")),
  country: z.string().min(1, "Country is required.").max(100, "Country is too long."),
})

export const paymentDetailsSchema = z.object({
  // TODO: validate better using validator library.
  cardNumber: z.string(),
  // TODO: validate better using zod. You may find useful dayjs which is installed for you.
  expirationMonth: z.coerce.number(),
  // TODO: validate better using zod.
  expirationYear: z.coerce.number(),
  cvv: z.string().min(1, 'Cvv is required.').pipe(z.coerce.number({
    invalid_type_error: 'Cvv is a number.',
  }).min(100, "Cvv is too small.").max(9999, 'Cvv is too large.')),
  holder: z.string().min(1, 'Card holder is required.').max(100, 'Card holder is too long.'),
})